import type { CSSProperties } from 'vue'
import type { Border, BorderSide } from '../types'
import { unit } from './unit'
import { isBorderSide, isSymmetric } from './is'

function borderSide(name: string, s: BorderSide | undefined): CSSProperties | undefined {
  if (s == null)
    return undefined

  const hasWidth = s.width != null
  const hasColor = s.color != null
  const hasStyle = s.style != null
  const r: Record<string, string | undefined> = {}
  if (hasColor)
    r[`${name}Color`] = s.color

  if (hasWidth)
    r[`${name}Width`] = unit(s.width)
  else if (hasColor)
    r[`${name}Width`] = '1px'

  if (hasStyle)
    r[`${name}Style`] = s.style
  else if (hasWidth || hasColor)
    r[`${name}Style`] = 'solid'

  return r
}

export function bordering(b: Border | undefined): CSSProperties | undefined {
  if (b == null)
    return undefined

  if (isBorderSide(b))
    return borderSide('border', b)

  if (isSymmetric(b)) {
    return {
      ...borderSide('borderBlock', b.vertical),
      ...borderSide('borderInline', b.horizontal),
    }
  }
  return {
    ...borderSide('borderTop', b.top),
    ...borderSide('borderBottom', b.bottom),
    ...borderSide('borderLeft', b.left),
    ...borderSide('borderRight', b.right),
  }
}
