/**
 * Calculate a 32 bit FNV-1a hash
 * Found here: https://gist.github.com/vaiorabbit/5657561
 * Ref.: http://isthe.com/chongo/tech/comp/fnv/
 *
 * @param {string} str the input value
 * @returns {string} return the 8-digit hex string
 */
export function hash(str: string): string {
  let hval = 0x811C9DC5
  for (let i = 0, l = str.length; i < l; i++) {
    hval ^= str.charCodeAt(i)
    hval += (hval << 1) + (hval << 4) + (hval << 7) + (hval << 8) + (hval << 24)
  }
  // Convert to 8 digit hex string
  return (`0000000${(hval >>> 0).toString(16)}`).slice(-8)
}
