import type { CSSProperties } from 'vue'
import type { Shadow } from '../types'

const unit = (n: number | undefined): string | undefined => n == null ? undefined : n === 0 ? n.toString() : `${n}px`

function stringify(s: Shadow | undefined): string | undefined {
  if (s == null)
    return undefined

  return [
    s.inset ? 'inset' : undefined,
    unit(s.x),
    unit(s.y),
    s.blur != null ? unit(s.blur) : s.spread != null ? '0' : undefined,
    unit(s.spread),
    s.color,
  ]
    .filter(n => n != null)
    .join(' ')
}

export function shadowing(ss: Shadow | Shadow[] | undefined): CSSProperties | undefined {
  if (ss == null)
    return undefined

  if (!Array.isArray(ss)) {
    return {
      boxShadow: stringify(ss),
    }
  }
  return {
    boxShadow: ss
      .map(stringify)
      .filter(Boolean)
      .join(', '),
  }
}
